<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Przeglądarka zdjęć Deepin</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Wersja:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>obraz</translation>
    </message>
    <message>
        <source>images</source>
        <translation>obrazy</translation>
    </message>
    <message>
        <source>album</source>
        <translation>album</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>albumy</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Zarządzanie synchronizacją</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Synchronizacja:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nowy album</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Bez nazwy</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Ostatnio zaimportowane</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje ulubione</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Czy na pewno chcesz usunąć ten album?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje ulubione</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Oś czasu</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Możesz dodać synchronizowany katalog lub złapać i upuścić obrazy na osi czasu</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Bez nazwy</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Pokaz zdjęć</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Przeglądarka zdjęć Deepin</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Obrazy</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Czy na pewno chcesz dodać obrazy do tego albumu?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Synchronizuj i utwórz</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Synchronizacja</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Czy na pewno chcesz dodać do listy synchronizowanej i utworzyć nazwany album po tym katalogu?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG (*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Pomyślnie wyeksportowano</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Błąd eksportu</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Czy na pewno chcesz wyrzucić zdjęcia do kosza?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Informacje o obrazie</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Ten plik zawiera wiele stron, których przejrzenie możliwe jest w programie Evince.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Pokaz zdjęć</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopiuj do schowka</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Usuń z albumu</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Obróć zgodnie z kierunkiem wskazówek zegara</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Obróć odwrotnie do kierunku wskazówek zegara</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Ustaw jako tło pulpitu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Wyświetl w menedżerze plików</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacje o obrazie</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Możesz dodać synchronizowany katalog lub złapać i upuścić obrazy na osi czasu</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Dodaj do albumu</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Dodaj do nowego albumu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Otwórz katalog</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nie masz uprawnień do podglądu obrazów</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Rodzaj</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Data fotografowania</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data modyfikacji</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Wymiar</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Rozmiar pliku</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Przestrzeń kolorów</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Tryb ekspozycji</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program ekspozycji</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Czas ekspozycji</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Lampa błyskowa</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Przysłona</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Ogniskowa</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maksymalna przysłona</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Tryb pomiaru</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balans bieli</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Korekcja lampy błyskowej</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model aparatu</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model obiektywu</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Brak skalowania</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Dopasuj stronę do obrazu</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Dopasuj obraz do strony</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Zeskaluj do:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milimetry</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centymetry</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Cale</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Położenie obrazu</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Skalowanie</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Ustawienia obrazu</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Ustawienia obrazu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Żaluzja</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Przełącznik</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Poślizg</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Siatka</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Wybierz katalog</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Wyłączono synchronizację dla tego katalogu</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Dodaj katalog</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Zarządzanie synchronizowanymi katalogami</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Lista katalogów jest pusta</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Anuluj synchronizację</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Urządzenie zostało usunięte</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Ten katalog już nie istnieje </translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Obliczanie...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Podgląd obrazu</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Pokaz zdjęć</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Zakończ pokaz</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Usuń z albumu</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Obróć zgodnie z kierunkiem wskazówek zegara</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Obróć odwrotnie do kierunku wskazówek zegara</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Ustaw jako tło pulpitu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Wyświetl w menedżerze plików</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacje o obrazie</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Poprzedni</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Następny</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Poprzedni ekran</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Następny ekran</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nowy album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Wyświetl skróty</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Prosimy wprowadzić nowy skrót</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Podgląd obrazu</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Przywróć domyślne</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Pokaz zdjęć</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Zakończ pokaz</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Usuń z albumu</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Obróć zgodnie z kierunkiem wskazówek zegara</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Obróć odwrotnie do kierunku wskazówek zegara</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Ustaw jako tło pulpitu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Wyświetl w menedżerze plików</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacje o obrazie</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nowy album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Zakończ pokaz</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Wstrzymaj/Odtwarzaj</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Ustawienia pokazu</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Efekt przejścia</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Czas trwania</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Przełącz czas trwania</translation>
    </message>
    <message>
        <source>second</source>
        <translation>sekunda</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Wstecz</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Zarządzanie obrazem</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje ulubione</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Rozmiar 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Dopasuj do okna</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Obróć odwrotnie do kierunku wskazówek zegara</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Obróć zgodnie z kierunkiem wskazówek zegara</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nie odnaleziono plików z obrazami</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otwórz obraz</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 obraz</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 obrazy</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Zarządzanie synchronizacją</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Synchronizacja:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Możesz dodać synchronizowany katalog lub złapać i upuścić obrazy na osi czasu</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Dodaj do albumu</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Dodaj do nowego albumu</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Pokaz zdjęć</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopiuj do schowka</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Obróć zgodnie z kierunkiem wskazówek zegara</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Obróć odwrotnie do kierunku wskazówek zegara</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Ustaw jako tło pulpitu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Wyświetl w menedżerze plików</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacje o obrazie</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Ustawienia pokazu</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Czas trwania</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Podgląd</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje ulubione</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Ostatnio zaimportowane</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nowy album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Przeglądarka zdjęć Deepin jest modnym i płynnie działającym menedżerem obrazów.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Wyposażony jest w funkcje zarządzania obrazami, podglądu obrazów i podstawowej ich modyfikacji.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Ciemny motyw</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Przeglądarka zdjęć Deepin to narzędzie przeglądania obrazów z modnym interfejsem i płynnym działaniem.</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Oś czasu</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Dodaj do albumu</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Dodaj do nowego albumu</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Wyjdź z pełnego ekranu</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pełny ekran</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Pokaz zdjęć</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drukuj</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopiuj do schowka</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Usuń z albumu</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Pokaż okno nawigacyjne</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Ukryj okno nawigacyjne</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Obróć zgodnie z kierunkiem wskazówek zegara</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Obróć odwrotnie do kierunku wskazówek zegara</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Ustaw jako tło pulpitu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Wyświetl w menedżerze plików</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacje o obrazie</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otwórz obraz</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Wszystkie obrazy</translation>
    </message>
</context>
</TS>